import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class ButtonWidget extends StatelessWidget {
  final String label;
  final double sizeText;
  final Color background;
  final Color color;
  final IconData icon;
  final VoidCallback onPressed;
  final double width;
  final double height;
  final double sizeIcon;
  final double borderRadius;
  final EdgeInsetsGeometry margin;
  final EdgeInsetsGeometry padding;
  final AlignmentGeometry alignment;
  final double elevation;

  const ButtonWidget(
      {@required this.label,
      @required this.onPressed,
      this.background,
      this.color,
      this.icon,
      this.width,
      this.sizeText = 16,
      this.sizeIcon = 20,
      this.borderRadius = 8,
      this.padding,
      this.margin,
      this.height = 20,
      this.alignment = Alignment.center,
      this.elevation = 10});

  @override
  Widget build(BuildContext context) {
    return Center(
      child: Container(
          padding: margin,
          width: width,
          child: ElevatedButton(
            child: Container(
              height: height,
              child: Row(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: <Widget>[
                  Icon(
                    icon,
                    color: color,
                    size: sizeIcon,
                  ),
                  Container(
                    padding: EdgeInsets.only(left: 5),
                    child: Text(
                      label,
                      style: TextStyle(color: color, fontSize: sizeText),
                    ),
                  ),
                ],
              ),
            ),
            onPressed: onPressed,
            style: ButtonStyle(
                elevation: MaterialStateProperty.all(elevation),
                backgroundColor: MaterialStateProperty.all(background),
                padding: MaterialStateProperty.all(padding),
                alignment: alignment,
                shape: MaterialStateProperty.all<RoundedRectangleBorder>(RoundedRectangleBorder(
                  borderRadius: BorderRadius.circular(borderRadius),
                ))),
          )),
    );
  }
}
